package
Version:
v0.0.0-...-7204636
Opens a new window with list of versions in this module.
Published: Sep 25, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Ciphers with Arbitrary Finite Domain (CAFD)
type CAFD[T any] struct {
}
func NewCAFD[T any](e []T) *CAFD[T]
func (c *CAFD[T]) Next() interface{}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.